searchNodes=[{"doc":"Efficiently store and index a set of non-negative integers. A set can be constructed using IntSet.new/0 : iex&gt; IntSet . new ( ) IntSet . new ( [ ] ) An IntSet obeys the same set semantics as MapSet , and provides constant-time operations for insertion, deletion, and membership checking. Use Enum.member?/2 to check for membership. iex&gt; IntSet . new ( 3 ) |&gt; Enum . member? ( 3 ) true Sets also implement Collectable , so it can collect values in any context that a list can: iex&gt; Enum . into ( [ 1 , 2 , 3 ] , IntSet . new ( ) ) IntSet . new ( [ 1 , 2 , 3 ] ) Working with applications that use bitstrings becomes way easier, because IntSet.new/1 accepts a bitstring, and IntSet.bitstring/2 can return one. iex&gt; IntSet . new ( 5 ) |&gt; IntSet . bitstring ( ) &lt;&lt; 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 1 :: 1 , 0 :: 1 , 0 :: 1 &gt;&gt; iex&gt; IntSet . new ( &lt;&lt; 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 1 :: 1 &gt;&gt; ) IntSet . new ( [ 5 ] ) Performance An IntSet is significantly faster than Elixir's MapSet at set operations (union, intersection, difference, equality), but slower at everything else. The case for memory usage is similar: better than MapSet for set operations, worse for everything else. Op MapSet IntSet Comparison new 4.8K 2.46K 1.95x slower member? 6.78M 2.93M 2.31x slower put 4.19M 1.15M 3.66x slower union 156.4K 944.31K 6.04x faster difference 48.09 891.27K 18.53x faster intersection 14.03K 905.70K 64.54x faster equal? 0.26M 2.41M 9.25x faster There is a benchmark checked into the project repo at perf/performance_test.exs . You can run it with mix run to see some results for yourself. Serialization With the use of IntSet.bitstring/2 , and IntSet.new/1 , you can serialize this collection very efficiently. iex&gt; IntSet . new ( [ 4 , 8 , 15 , 16 , 23 , 42 ] ) |&gt; IntSet . bitstring ( ) |&gt; Base . encode16 ( ) &quot;088181000020&quot; iex&gt; Base . decode16! ( &quot;088181000020&quot; ) |&gt; IntSet . new ( ) IntSet . new ( [ 4 , 8 , 15 , 16 , 23 , 42 ] )","ref":"IntSet.html","title":"IntSet","type":"module"},{"doc":"Get a bitstring representing the members of a set. Examples iex&gt; IntSet . new ( 0 ) |&gt; IntSet . bitstring ( ) &lt;&lt; 128 &gt;&gt; iex&gt; IntSet . new ( 5 ) |&gt; IntSet . bitstring ( ) &lt;&lt; 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 1 :: 1 , 0 :: 1 , 0 :: 1 &gt;&gt; iex&gt; IntSet . new ( ) |&gt; IntSet . bitstring ( ) &lt;&lt; &gt;&gt;","ref":"IntSet.html#bitstring/1","title":"IntSet.bitstring/1","type":"function"},{"doc":"Remove a number from the int set. Examples iex&gt; set = IntSet . new ( 5 ) IntSet . new ( [ 5 ] ) iex&gt; IntSet . delete ( set , 5 ) IntSet . new ( [ ] )","ref":"IntSet.html#delete/2","title":"IntSet.delete/2","type":"function"},{"doc":"Returns a set that is int_set1 without the members of int_set2 . Examples iex&gt; IntSet . difference ( IntSet . new ( [ 1 , 2 ] ) , IntSet . new ( [ 2 , 3 , 4 ] ) ) IntSet . new ( [ 1 ] )","ref":"IntSet.html#difference/2","title":"IntSet.difference/2","type":"function"},{"doc":"Checks if int_set and int_set2 have no members in common. Examples iex&gt; IntSet . disjoint? ( IntSet . new ( [ 1 , 2 ] ) , IntSet . new ( [ 3 , 4 ] ) ) true iex&gt; IntSet . disjoint? ( IntSet . new ( [ 1 , 2 ] ) , IntSet . new ( [ 2 , 3 ] ) ) false","ref":"IntSet.html#disjoint?/2","title":"IntSet.disjoint?/2","type":"function"},{"doc":"Checks if two sets are equal Examples iex&gt; IntSet . equal? ( IntSet . new ( [ 1 , 2 ] ) , IntSet . new ( [ 2 , 1 , 1 ] ) ) true iex&gt; IntSet . equal? ( IntSet . new ( [ 1 , 2 ] ) , IntSet . new ( [ 3 , 4 ] ) ) false","ref":"IntSet.html#equal?/2","title":"IntSet.equal?/2","type":"function"},{"doc":"Find all elements that are in both int_set1 and int_set2 . Examples iex&gt; IntSet . intersection ( IntSet . new ( [ 1 , 2 ] ) , IntSet . new ( [ 2 , 3 , 4 ] ) ) IntSet . new ( [ 2 ] ) iex&gt; IntSet . intersection ( IntSet . new ( [ 1 , 2 ] ) , IntSet . new ( [ 3 , 4 ] ) ) IntSet . new ( [ ] )","ref":"IntSet.html#intersection/2","title":"IntSet.intersection/2","type":"function"},{"doc":"Returns a set of size n with all members not in the given IntSet. You can visualize this operation as calling IntSet.difference/2 with the first argument being a full IntSet of size n. Examples iex&gt; IntSet . new ( 0 ) |&gt; IntSet . inverse ( 1 ) IntSet . new ( [ ] ) iex&gt; IntSet . new ( 0 ) |&gt; IntSet . inverse ( 8 ) IntSet . new ( [ 1 , 2 , 3 , 4 , 5 , 6 , 7 ] ) iex&gt; IntSet . new ( ) |&gt; IntSet . inverse ( 3 ) IntSet . new ( [ 0 , 1 , 2 ] ) iex&gt; IntSet . new ( ) |&gt; IntSet . inverse ( 9 ) IntSet . new ( [ 0 , 1 , 2 , 3 , 4 , 5 , 6 , 7 , 8 ] )","ref":"IntSet.html#inverse/2","title":"IntSet.inverse/2","type":"function"},{"doc":"Create an empty int set. Examples iex&gt; IntSet . new IntSet . new ( [ ] )","ref":"IntSet.html#new/0","title":"IntSet.new/0","type":"function"},{"doc":"Create an int set with some starting value. Examples You can create a set with a single starting value. iex&gt; IntSet . new ( 0 ) IntSet . new ( [ 0 ] ) You can also provide an enumerable of integers to start with. iex&gt; IntSet . new ( [ 1 , 2 , 3 ] ) IntSet . new ( [ 1 , 2 , 3 ] ) Lastly, you can initialize the set with a bit string. Binary strings are interpreted as little-endian, with the very first bit of the string representing the number zero. iex&gt; IntSet . new ( &lt;&lt; 1 :: 1 &gt;&gt; ) IntSet . new ( [ 0 ] ) iex&gt; IntSet . new ( &lt;&lt; 0b1000_1000 &gt;&gt; ) IntSet . new ( [ 0 , 4 ] ) iex&gt; IntSet . new ( &lt;&lt; 0 :: 1 &gt;&gt; ) IntSet . new ( [ ] )","ref":"IntSet.html#new/1","title":"IntSet.new/1","type":"function"},{"doc":"Add a value to the int set. Examples iex&gt; set = IntSet . new ( ) IntSet . new ( [ ] ) iex&gt; IntSet . put ( set , 0 ) IntSet . new ( [ 0 ] )","ref":"IntSet.html#put/2","title":"IntSet.put/2","type":"function"},{"doc":"Create a new set that contains all of the elements of both x and y. Examples iex&gt; a = IntSet . new ( 7 ) iex&gt; b = IntSet . new ( 4 ) iex&gt; IntSet . union ( a , b ) IntSet . new ( [ 4 , 7 ] )","ref":"IntSet.html#union/2","title":"IntSet.union/2","type":"function"},{"doc":"","ref":"IntSet.html#t:t/0","title":"IntSet.t/0","type":"opaque"},{"doc":"A time- and memory-efficient data structure for positive integers. Faster than Elixir's MapSet at set operations (union, intersection, difference, equality), and slower at everything else. Also can be serlialized wicked small.","ref":"readme.html","title":"IntSet","type":"extras"},{"doc":"This package can be installed by adding int_set to your list of dependencies in mix.exs : def deps do [ { :int_set , &quot;~&gt; 1.5&quot; } ] end The docs can be found at https://hexdocs.pm/int_set .","ref":"readme.html#install","title":"IntSet - Install","type":"extras"},{"doc":"Usage is pretty much the same as with MapSet , but you're only allowed to put positive integers (including zero) into the set. A set can be constructed using IntSet.new/0 : iex&gt; IntSet . new ( ) IntSet . new ( [ ] ) An IntSet obeys the same set semantics as MapSet , and provides constant-time operations for insertion, deletion, and membership checking. Use Enum.member?/2 to check for membership. iex&gt; IntSet . new ( 3 ) |&gt; Enum . member? ( 3 ) true Sets also implement Collectable , so it can collect values in any context that a list can: iex&gt; Enum . into ( [ 1 , 2 , 3 ] , IntSet . new ( ) ) IntSet . new ( [ 1 , 2 , 3 ] ) The inspect/1 implementation for IntSet sorts the members, which makes it way easier to write doctests: iex&gt; IntSet . new ( [ 3 , 1 , 2 ] ) IntSet . new ( [ 1 , 2 , 3 ] ) Working with applications that use bitstrings becomes way easier, because IntSet.new/1 accepts a bitstring, and IntSet.bitstring/2 can return one. iex&gt; IntSet . new ( 5 ) |&gt; IntSet . bitstring ( ) &lt;&lt; 4 &gt;&gt; iex&gt; IntSet . new ( &lt;&lt; 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 0 :: 1 , 1 :: 1 &gt;&gt; ) IntSet . new ( [ 5 ] ) This also means that an IntSet can be really efficiently serialized with the use of IntSet.bitstring/2 , and IntSet.new/1 . iex&gt; IntSet . new ( [ 4 , 8 , 15 , 16 , 23 , 42 ] ) |&gt; IntSet . bitstring ( ) |&gt; Base . encode16 ( ) &quot;088181000020&quot; iex&gt; Base . decode16! ( &quot;088181000020&quot; ) |&gt; IntSet . new ( ) IntSet . new ( [ 4 , 8 , 15 , 16 , 23 , 42 ] )","ref":"readme.html#usage","title":"IntSet - Usage","type":"extras"},{"doc":"Check out the iterations-per-second for some operations of MapSet compared to IntSet . Op MapSet IntSet Comparison new 4.8K 2.46K 1.95x slower member? 6.78M 2.93M 2.31x slower put 4.19M 1.15M 3.66x slower union 156.4K 944.31K 6.04x faster difference 48.09 891.27K 18.53x faster intersection 14.03K 905.70K 64.54x faster equal? 0.26M 2.41M 9.25x faster Memory usage is also better for union, difference, intersection, and equality. See the [ benchmarks/results ] directory for all the benchmarks. You can run the benchmarks for yourself with mix run benchmarks/benchmark.exs .","ref":"readme.html#performance","title":"IntSet - Performance","type":"extras"},{"doc":"This project was developed by Rosa Richter . You can get in touch with her on Keybase.io .","ref":"readme.html#maintainer","title":"IntSet - Maintainer","type":"extras"},{"doc":"Questions and pull requests are more than welcome. I follow Elixir's tenet of bad documentation being a bug, so if anything is unclear, please file an issue ! Ideally, my answer to your question will be in an update to the docs. Please see CONTRIBUTING.md for all the details you could ever want about helping me with this project. Note that this project is released with a Contributor Code of Conduct . By participating in this project you agree to abide by its terms.","ref":"readme.html#contributing","title":"IntSet - Contributing","type":"extras"},{"doc":"MIT License Copyright 2022 Rosa Richter Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"readme.html#license","title":"IntSet - License","type":"extras"},{"doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"","ref":"changelog.html#unreleased","title":"Changelog - Unreleased","type":"extras"},{"doc":"Changed Inspecting an IntSet now returns a string using IntString.new([1, 2, 3, ...]) syntax. The internal binary that IntSet uses to store values is now always byte-aligned, and each byte has changed endianness to allow for some internal optimizations. Binaries returned by IntSet.bitstring/1 is now always byte-aligned. Removed BREAKING: The byte_align option for IntSet.bitstring/1 was removed.","ref":"changelog.html#2-0-0-2023-03-29","title":"Changelog - 2.0.0 - 2023-03-29","type":"extras"},{"doc":"Added Copyright headers are now on all files, following the REUSE Specification . Changed Fixes for Elixir 1.14 deprecations The project now uses Earthly for CI. You can run the entire CI pipeline on your local machine by installing Earthly and running earthly +all .","ref":"changelog.html#1-5-2-2022-09-05","title":"Changelog - 1.5.2 - 2022-09-05","type":"extras"},{"doc":"Added Sponshorship link to mix.exs Fixed inspect/2 no longer renders certain sets as charlists.","ref":"changelog.html#1-5-1-2021-09-12","title":"Changelog - 1.5.1 - 2021-09-12","type":"extras"},{"doc":"Changed IntSet.bitstring/1 is now IntSet.bitstring/2 and now accepts an option: :byte_align . When this option is set to true , the bitstring is padded at the end to make it byte-aligned.","ref":"changelog.html#1-5-0-2020-10-10","title":"Changelog - 1.5.0 - 2020-10-10","type":"extras"},{"doc":"Fixed IntSet.inverse/2 is now totally fixed.","ref":"changelog.html#1-4-2-2019-11-24","title":"Changelog - 1.4.2 - 2019-11-24","type":"extras"},{"doc":"Fixed Some problems with IntSet.inverse/2 and padding were fixed.","ref":"changelog.html#1-4-1-2019-11-24","title":"Changelog - 1.4.1 - 2019-11-24","type":"extras"},{"doc":"Added The IntSet.inverse/2 function, which is like taking the difference of your IntSet with a completely-full IntSet with n members. Say you have a list of indices, and you want to create a list of all the indices you don't have. Just take the inverse, providing a member limit. Added an .editorconfig file to the project.","ref":"changelog.html#1-4-0-2019-11-24","title":"Changelog - 1.4.0 - 2019-11-24","type":"extras"},{"doc":"Added The IntSet.equal?/2 function. It does exactly what you think. The IntSet.intersection/2 function. Returns the elements that are in both sets.","ref":"changelog.html#1-3-0-2018-05-25","title":"Changelog - 1.3.0 - 2018-05-25","type":"extras"},{"doc":"Added IntSet.difference/2 now has a typespec. IntSet.disjoint?/2 now has docs and a typespec. Changed IntSet.union/2 has been optimized","ref":"changelog.html#1-2-1-2018-02-09","title":"Changelog - 1.2.1 - 2018-02-09","type":"extras"},{"doc":"Added The IntSet.difference/2 function. This function subtracts set B's members from set A. The IntSet.disjoint?/2 function. Returns true if sets A and B have no members in common. Changed The Collectable implementation was dramatically optimized.","ref":"changelog.html#1-2-0-2018-02-06","title":"Changelog - 1.2.0 - 2018-02-06","type":"extras"},{"doc":"Added The IntSet.bitstring/1 function. Returns a binary with bits flipped at the indices at which the set has members. For example, say you have a set containing 0, 1, and 4. Calling IntSet.bitstring/1 on that set will return a five-bit-long binary with the first, second, and fifth bits set to 1, and the rest are 0. The library is now typespecced and documented.","ref":"changelog.html#1-1-0-2018-02-03","title":"Changelog - 1.1.0 - 2018-02-03","type":"extras"},{"doc":"Added Constructor IntSet.new/0 , which creates a new empty set. Constructor IntSet.new/1 , which accepts either an enumerable and returns a set containing those elements. This constructor also accepts a bitstring. See the documentation for details on that behavior. The IntSet.put/2 function. Just like MapSet.put/2 , this function returns a new set with the given value added. The IntSet.delete/2 function. Again, just like MapSet.delete/2 . Returns a new set with the given value removed. The IntSet.union/2 function. Returns a set that contains elements of both given sets. An implementation of Inspect that sorts members before printing them, so the order can be relied upon in doctests. An implementation of Collectable . An implementation of Enumerable .","ref":"changelog.html#1-0-0-2018-02-01","title":"Changelog - 1.0.0 - 2018-02-01","type":"extras"},{"doc":"","ref":"code_of_conduct.html","title":"Contributor Covenant Code of Conduct","type":"extras"},{"doc":"We as members, contributors, and leaders pledge to make participation in our community a harassment-free experience for everyone, regardless of age, body size, visible or invisible disability, ethnicity, sex characteristics, gender identity and expression, level of experience, education, socio-economic status, nationality, personal appearance, race, religion, or sexual identity and orientation. We pledge to act and interact in ways that contribute to an open, welcoming, diverse, inclusive, and healthy community.","ref":"code_of_conduct.html#our-pledge","title":"Contributor Covenant Code of Conduct - Our Pledge","type":"extras"},{"doc":"Examples of behavior that contributes to a positive environment for our community include: Demonstrating empathy and kindness toward other people Being respectful of differing opinions, viewpoints, and experiences Giving and gracefully accepting constructive feedback Accepting responsibility and apologizing to those affected by our mistakes, and learning from the experience Focusing on what is best not just for us as individuals, but for the overall community Examples of unacceptable behavior include: The use of sexualized language or imagery, and sexual attention or advances of any kind Trolling, insulting or derogatory comments, and personal or political attacks Public or private harassment Publishing others' private information, such as a physical or email address, without their explicit permission Other conduct which could reasonably be considered inappropriate in a professional setting","ref":"code_of_conduct.html#our-standards","title":"Contributor Covenant Code of Conduct - Our Standards","type":"extras"},{"doc":"Community leaders are responsible for clarifying and enforcing our standards of acceptable behavior and will take appropriate and fair corrective action in response to any behavior that they deem inappropriate, threatening, offensive, or harmful. Community leaders have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct, and will communicate reasons for moderation decisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities","title":"Contributor Covenant Code of Conduct - Enforcement Responsibilities","type":"extras"},{"doc":"This Code of Conduct applies within all community spaces, and also applies when an individual is officially representing the community in public spaces. Examples of representing our community include using an official e-mail address, posting via an official social media account, or acting as an appointed representative at an online or offline event.","ref":"code_of_conduct.html#scope","title":"Contributor Covenant Code of Conduct - Scope","type":"extras"},{"doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be reported to the community leaders responsible for enforcement by sending a message to Rosa Richter on keybase.io . All complaints will be reviewed and investigated promptly and fairly. All community leaders are obligated to respect the privacy and security of the reporter of any incident.","ref":"code_of_conduct.html#enforcement","title":"Contributor Covenant Code of Conduct - Enforcement","type":"extras"},{"doc":"Community leaders will follow these Community Impact Guidelines in determining the consequences for any action they deem in violation of this Code of Conduct: 1. Correction Community Impact : Use of inappropriate language or other behavior deemed unprofessional or unwelcome in the community. Consequence : A private, written warning from community leaders, providing clarity around the nature of the violation and an explanation of why the behavior was inappropriate. A public apology may be requested. 2. Warning Community Impact : A violation through a single incident or series of actions. Consequence : A warning with consequences for continued behavior. No interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, for a specified period of time. This includes avoiding interactions in community spaces as well as external channels like social media. Violating these terms may lead to a temporary or permanent ban. 3. Temporary Ban Community Impact : A serious violation of community standards, including sustained inappropriate behavior. Consequence : A temporary ban from any sort of interaction or public communication with the community for a specified period of time. No public or private interaction with the people involved, including unsolicited interaction with those enforcing the Code of Conduct, is allowed during this period. Violating these terms may lead to a permanent ban. 4. Permanent Ban Community Impact : Demonstrating a pattern of violation of community standards, including sustained inappropriate behavior, harassment of an individual, or aggression toward or disparagement of classes of individuals. Consequence : A permanent ban from any sort of public interaction within the community.","ref":"code_of_conduct.html#enforcement-guidelines","title":"Contributor Covenant Code of Conduct - Enforcement Guidelines","type":"extras"},{"doc":"This Code of Conduct is adapted from the Contributor Covenant , version 2.0, available at https://www.contributor-covenant.org/version/2/0/code_of_conduct.html . Community Impact Guidelines were inspired by Mozilla's code of conduct enforcement ladder . For answers to common questions about this code of conduct, see the FAQ at https://www.contributor-covenant.org/faq . Translations are available at https://www.contributor-covenant.org/translations .","ref":"code_of_conduct.html#attribution","title":"Contributor Covenant Code of Conduct - Attribution","type":"extras"},{"doc":"Thank you for considering contributing! I write libraries in my free time and contributions from others help me make great tools. Following these guidelines helps to communicate that you respect my time, as the developer managing and developing this open source project. In return, I should reciprocate that respect in addressing your issue, assessing changes, and helping you finalize your pull requests. Questions and pull requests are more than welcome. I follow Elixir's tenet of bad documentation being a bug, so if anything is unclear, please file an issue ! Ideally, my answer to your question will be in an update to the docs. Please note that this project is released with a Contributor Code of Conduct . By participating in this project you agree to abide by its terms. Working on your first Pull Request? You can learn how from this free series How to Contribute to an Open Source Project on GitHub .","ref":"contributing.html","title":"Contributing","type":"extras"},{"doc":"Follow the Code of Conduct . Keep your commits clear and your pull requests small. This isn't a big library. Run mix format on your files before committing them. I like clean diffs. Run mix credo and resolve anything of yours that comes up. No dependencies.","ref":"contributing.html#ground-rules","title":"Contributing - Ground Rules","type":"extras"},{"doc":"Ask questions! I like writing good documentation, and questions make that work more meaningful. Use the issue tracker for questions. There's a questions tag on the issue tracker for that reason. Tests are always welcome! If you've got some edge case you're worried about, help me test for it! Searching issues or pull requests tagged &quot; help wanted &quot; or &quot; good first issue &quot; are great places to get started.","ref":"contributing.html#your-first-contribution","title":"Contributing - Your First Contribution","type":"extras"},{"doc":"GitHub makes it really easy to submit pull requests. Just: Create your own fork of the code Do the changes in your fork Submit a pull request I don't require a CLA or anything like that.","ref":"contributing.html#getting-started","title":"Contributing - Getting Started","type":"extras"},{"doc":"If you find a security vulnerability, do NOT open an issue. Contact Rosa on keybase.io instead! In order to determine whether you are dealing with a security issue, ask yourself these two questions: Can I access something that's not mine, or something I shouldn't have access to? Can I disable something for other people? If the answer to either of those two questions are &quot;yes&quot;, then you're probably dealing with a security issue. Note that even if you answer &quot;no&quot; to both questions, you may still be dealing with a security issue, so if you're unsure, message me directly . Please open an issue and follow the directions in the issue template.","ref":"contributing.html#how-report-a-bug","title":"Contributing - How report a bug","type":"extras"},{"doc":"The philosopy of this project is to create a small, sharp tool that takes some burden off of the shoulders of developers. Feature requests and enhancements should stick to this philosophy. Help me do anything that lets developers do more with their valuable time. Feature requests give meaning to my work. Open an issue that decribes the feature you'd like to see, why you need it, and how you'd like it to work.","ref":"contributing.html#how-to-suggest-a-feature-or-enhancement","title":"Contributing - How to suggest a feature or enhancement","type":"extras"},{"doc":"As the primary developer, I will be the one reviewing all pull requests. I check GitHub almost every day, so you should be able to hear back from me quickly. However, I only do this in my free time, so please allow me flexibility. If you like this contribution guide, please give a star to Nadia Eghbal 's contributing-template project on GitHub. It was a great help.","ref":"contributing.html#code-review-process","title":"Contributing - Code review process","type":"extras"}]